function foveon_processed = Foveon2OtherFormat_single(foveon, method, downsize, IRfilter, showpic, f_number, integrationtime)

% Default program to convert a batch of files from Foveon camera rgb to
% any other format (see list). input parameters are:

% showpic :  whether it shows a suitably scaled version of the picture being
%            converted (the default is NO)
% makejpg :  whether it makes a pretty jpg version of the picture being
%            processed in a subsidiary directory called "/pics" (the
%            default is YES)
% IRfilter : whether the IR-blocking filter was used in during the image
%            capture (used for bakwards compatibility with databases
%            gathered WITHOUT the filter) (the default is FILTER ON)
% downsize : since the original foveon files are quite big (2268 x 1512) you are given
%            the option of downsizing. The default is downsize = 0 (NO changes)
%            another popular option is downsize = 0.5 (half-size).
% method   : this determines the choice of polynomial coversion.
%            There are seveal flavours to date (see the test_all_poly_options,
%            but the most common use of this code is to convert the pictures to 
%            the Stockmann & Sharpe LMS fundamentals using the datset of Munsell 
%            chip reflectances as a training set (method = SS_LMS_Munsell)
%            or to convert them to the standard CIE1931 XYZ tristimulus
%            values using the datset of Munsell chip reflectances as a training 
%            set (method = CIE1931_XYZ_Munsell). The complete set of options are: 
%            SP_LMS_Munsell: Smith & Pokorny LMS (normalised to max=1) and Munsell chips 
%            SP_LMS_NE     : Smith & Pokorny LMS (normalised to max=1) and NE reflectances
%            SS_LMS_Munsell: Stockmann & Sharpe 2000 LMS (normalised to max=1) and Munsell chips
%            SS_LMS_NE     : Stockmann & Sharpe 2000 LMS (normalised to max=1) and NE reflectances 
%            CIE1931_XYZ_Munsell : CIE1931 XYZ (normalised to max=1) and Munsell chips
%            CIE1931_XYZ_NE      : CIE1931 XYZ (normalised to max=1) and NE reflectances
%            JV1978_XYZ_Munsell  : Judd-Voss 1978 XYZ (normalised to max=1) and Munsell chips
%            JV1978_XYZ_NE       : Judd-Voss 1978 XYZ (normalised to max=1) and NE reflectances
%foveon  : either the picture itself or its name (where the original picture is located). 

%===============================
if (nargin < 7) || isempty(integrationtime)
        integrationtime = 1/250; % estimated from a typica sunny image of Barcelona
end

if (nargin < 6) || isempty(f_number)
        f_number = 7.1; % estimated from a typica sunny image of Barcelona
end

if (nargin < 5)  || isempty(showpic)
    showpic = 0;
end

if (nargin < 4)  || isempty(IRfilter)
    IRfilter = 1;
end

if (nargin < 3)  || isempty(downsize)
    downsize = 0;
end

if (nargin <2)  || isempty(method)
    method = 'cie1931_xyz_munsell';
end

if ischar(foveon)
    [destinpath, name, ext, versn] = fileparts(foveon);
    if ~strcmpi(ext,'.X3F')
        error('wrong file extension');
    end
    h = read_x3f_header(foveon);
    f_number = str2double(h.APERTURE);
    integrationtime = str2double(h.SHUTTER);
    foveon = double(readfoveonpic(foveon));
end

[M SumSQResid] = generate_polyparam(method, IRfilter, 0);
 
if downsize
    foveon = imresize(foveon, downsize);
end

if showpic
    figure; imagesc(  (foveon - min(foveon(:))) ./ ( max(foveon(:)) -min(foveon(:)) ) );
end
foveon_processed = fovRGB2OtherFormat(foveon, M, f_number, integrationtime);   

