function [mI, sI, col_ave, row_ave] = basic_analysis(I)

% BASIC_ANALYSIS   - Calculates mean, std, column averages and row averages
%                    from single image
%
% Function call:    [mI,sI,col_ave,row_ave] = basic_analysis(I);
%
% In:   I           3D-image (if not given, uses uigetfile for file name)
%
% Out:  mI          Color component mean values
%       sI          Color component std values
%       col_ave     Color component column averages
%       row_ave     Color component row averages

% (c) Heli Hytti 15.12.2005
% HH 22.2.2006: arbitrary number of color channels

if (nargin<1 | isempty(I)), [f, p] = uigetfile('*.*','Select image file');
  ext = f(end-2:end);
  I = readraw([p f],'O');
end

I = double(I);

[R,C,L] = size(I),

if L==1, cnames = 'Grayscale'; lcolor = 'k'; lmarker = 'none';
elseif L==3, cnames = str2mat('Red','Green','Blue'); lcolor = str2mat('r','g','b'); lmarker = str2mat('.','+','x');
elseif L==4, cnames = str2mat('Red','G-red','Blue','G-blue'); lcolor = str2mat('r','g','b','g'); lmarker = str2mat('.','+','.','x');
end

mI = zeros(1,L); sI = mI;
col_ave = zeros(C,L);
row_ave = zeros(R,L);

for ii=1:L,
  comp = I(:,:,ii);
  mI(1,ii) = mean(comp(:));
  sI(1,ii) = std(comp(:));
  col_ave(:,ii) = mean(comp)';
  row_ave(:,ii) = mean(comp')';
end

disp(['Color component mean values (' reshape(cnames',1,length(cnames(:))) '):']), mI,
disp(['Color component std values (' reshape(cnames',1,length(cnames(:))) '):']), sI,
figure; 
for ii=1:L, h = line(1:C,col_ave(:,ii),'linestyle','-','linewidth',2,'color',lcolor(ii,:),'marker',lmarker(ii,:)); end
title('Column averages'); xlabel('Image column');

figure;  
for ii=1:L, h = line(1:R,row_ave(:,ii),'linestyle','-','linewidth',2,'color',lcolor(ii,:),'marker',lmarker(ii,:)); end
title('Row averages'); xlabel('Image row');
