function out = dcshot_dist(dname, ext, explev, Ngroup, index, ave_in)

% DCSHOT_DIST   - Calculates dark current shot noise for single exposure
%                 level for given (or random) image points
%
% Function call: out = dc_shotnoise(dname,ext,explev,Ngroup,index,ave_in);
%
% In:   dname       Directory name for data files
%       ext         file name extension (e.g. 'x3f')
%       explev      index of exposure level in directory dname to be analysed
%       Ngroup      Number of files in one exposure group (default = 100)
%       index       Index numbers for image points to be analysed
%                   (default = ten random points)
%       ave_in      cell array (output from ave_images) containing 
%                   ave_ch1, ave_ch2 etc; average dark images for color components 
%                   for wanted exposure level in matrix
%
% Out:  out         cell array containing shot_ch1, shot_ch2 etc; 
%                   [Ngroup x length(index)] matrices of pixel-by-pixel dc
%                   shot noise values

% (c) Heli Hytti 9.5.2005
% HH 23.2.2006: arbitrary number of color channels

% Default number of frames per exposure level is 100
if nargin<4, Ngroup = 100; end

% Add backslash to the end of directory name if it's missing
if dname(end)~='\', dname = [dname '\']; end

% Get file names in time order (monotonically increasing exposure level
% assumed)
F = files(dname,ext,'t');

% Find number of image files and calculate number of exposure levels
Ns = size(F,2);
Nexp = Ns/Ngroup;

% Read test image and get image size
I = readraw([dname F{1}],'O');
nw = size(I,2); nh = size(I,1); n = size(I,3);

% Pick ten random points
if nargin<5, index = round(rand(1,10)*nw*nh); end

% Initialize matrices
for ii=1:nc, eval(['shot_ch' num2str(ii) ' = zeros(Ngroup,length(index));']); 
  eval(['ch' num2str(ii) ' = zeros(nh,nw);']); 
end
I = zeros(nh,nw,n);

% Find appropriate data file index (first file in given exposure level)
k = (explev-1)*Ngroup+1;
% For Ngroup files repeat
for jj=1:Ngroup,
    % Read images
    I = readraw([dname F{k}],'O');
    % Separate color channels and calculate deviations from average image
    for kk=1:nc,
      ave_ch = ave_in{kk};
      eval(['ch' num2str(kk) '(:) = double(I(:,:,kk));']);
      eval(['shot_ch' num2str(kk) '(jj,:) = ch' num2str(kk) '(index)-ave_ch(index);']);
    end
    k = k+1;
end

out = cell(1,nc);
for ii=1:no, out(ii) = eval(['{shot_ch' num2str(ii) '};']); end



