function Nam = files(D, typ, opt)
% FILES  - Searces names of files of type typ in given directory (or list of directories) D
%
% Function call:  Nam = files(D, typ, opt);
%
% In:  D    root directory (default .)
%      typ  type (or list of types) of files to search (default all)
%           (type is considered case insensitive)
%      opt  option for filenames listed by name ('n', default) or date/time ('t')
%
% Out: Nam  list of names of found files

% (c) Heimo Ihalainen 22.5.2003
% 10.11.2004 Heli Hytti, sorting option opt added

if nargin<3, opt = 'n'; end
if nargin<2; typ = '*'; end
if nargin<1; D = '.'; end;

if iscell(D); Nam = {};
  for ii=1:prod(size((D))); N = dirfiles(D{ii}, typ, opt);
    for jj=1:length(N); Nam{ii,jj} = N{jj}; end
  end
else; Nam = dirfiles(D, typ, opt);
end

function Nam = dirfiles(D, typ, opt)
Nam = {};
if exist(D,'dir')==7; d = dir(D);
  if opt=='t', 
      dd = {d.date}; ddn = datenum(dd); [s,I] = sort(ddn);
      sd = {dd(I)};
      dn = {d.name}; sdn = {dn{I}};
      dby = {d.bytes}; sdby = {dby{I}};
      dbi = {d.isdir}; sdbi = {dbi{I}};
      d = struct('name',sdn,'date',sd,'bytes',sdby,'isdir',sdbi);
  end
  for ii=1:length(d);
    if exist([D '\' d(ii).name],'file')==2; n = max(findstr('.', d(ii).name));
      if isempty(n); s = ''; else; s = d(ii).name(n+1:end); end
      if iscell(typ);
        for jj=1:length(typ); t = typ{jj}; % next line complicated for '' and '.' types
          if strcmpi(s, t)|strcmpi(t,'*')|(t=='.'&isempty(s)); Nam{end+1} = d(ii).name; end
        end
      elseif strcmpi(s, typ)|strcmpi(typ,'*')|(typ=='.'&isempty(s)); Nam{end+1} = d(ii).name;
      end
    end
  end
end