function [VFPN,HFPN] = fpn(FSD,ave_in)

% FPN       - Analyses vertical and horizontal fixed pattern noise
%             (SMIA 1.0 characterization 5.2, 5.3)
%
% Function call:    [VFPN,HFPN] = fpn(FSD,ave_in);
%
% In:   FSD         Full scale deflection for camera 
%                   (max pixel output - min pixel output)
%       ave_in      cell array (output from ave_images) containing 
%                   ave_ch1, ave_ch2 etc; average color components 
%
% Out:  VFPN        Vertical fixed pattern noise for each color (% of FSD)
%       HFPN        Horizontal FPN for each color (% of FSD)

% (c) Heli Hytti 14.9.2005
% HH 23.2.2006: arbitrary number of color channels

nchans = nargin-1;
comp1 = ave_in{1};
[nr,nc,nl] = size(comp1);

VFPN = zeros(nl,nchans);
HFPN = zeros(nl,nchans);

for ii=1:nl,
  for jj=1:nchans,
    ave_ch = ave_in{jj};
    col_mean = mean(ave_ch(:,:,ii));
    row_mean = mean(ave_ch(:,:,ii)');
    VFPN(ii,jj) = (100/FSD)*sqrt((1/(nc-1))*sum(diff(col_mean).^2));
    HFPN(ii,jj) = (100/FSD)*sqrt((1/(nr-1))*sum(diff(row_mean).^2));
  end
end
