function h = immulti(I,lims)
% IMMULTI   - Displays multiple image frames as rectangular montage.
%
% Function call:   h = immulti(I,lims) 
%
% In:   I     M-by-N-by-K image matrix
%       lims  limits for gray level scaling (default: [globmin(I) globmax(I)])
%
% Out:  h    handle to the image object.

% (c) Heli Hytti 12.10.2004  

if nargin<2, lims = [globmin(I) globmax(I)]; end
% Correction for Clim data if needed
if lims(1)==lims(2), lims(1) = lims(1)-0.1; lims(2) = lims(2)+0.1; end

[R, C, F] = size(I);

% Estimate number of columns and rows given the desired ratio of
% Columns to Rows to be one (square montage).

if F==1, nCols = 1; nRows = 1;
else
    nCols = sqrt(R*F/C);
    nRows = F/nCols;
    % Make sure montage rows and columns are integers.
    nCols = ceil(nCols);
    nRows = ceil(F/nCols);
end

% Create the montage image.
b = I(1,1); % to inherit type 
b(1,1) = NaN; % from I
b = repmat(b, nRows*R, nCols*C);

rows = 1 : nRows; 
cols = 1 : nCols;

for ii = 0:nRows-1,
  for jj = 0:nCols-1,
    kk = jj + ii * nCols + 1;
    if kk <= F
      b((ii*R)+1:(ii+1)*R, (jj*C)+1:(jj+1)*C) = I(:,:,kk);
    else
      break;
    end
  end
end

h = imagesc(b,lims); set(gca,'xticklabel',[],'xtick',[],'yticklabel',[],'ytick',[]); colormap gray; colorbar









