function h = immulti_hist(I,blocks,lims)
% IMMULTI_HIST   - Displays multiple histogram image frames as rectangular montage.
%
% Function call:   h = immulti_hist(I,blocks,lims) 
%
% In:   I     M-by-N-by-K histogram image matrix
%       blocks      number of blocks (N_vertical x M_horizontal, default sqrt(size(I,3)))
%       lims  limits for gray level scaling (default: [globmin(I) globmax(I)])
%
% Out:  h    handle to the image object.

% (c) Heli Hytti 23.11.2005  

if nargin<3, lims = [globmin(I) globmax(I)]; end
if nargin<2, blocks = [sqrt(size(I,3)) sqrt(size(I,3))]; end

% Correction for Clim data if needed
if lims(1)==lims(2), lims(1) = lims(1)-0.1; lims(2) = lims(2)+0.1; end

[R, C, F] = size(I);

% Estimate number of columns and rows given the desired ratio of
% Columns to Rows to be one (square montage).

if F==1, nCols = 1; nRows = 1;
else
    nCols = blocks(2);
    nRows = blocks(1);
    % Make sure montage rows and columns are integers.
    nCols = ceil(nCols);
    nRows = ceil(F/nCols);
end

% Create the montage image.
b = I(1,1); % to inherit type 
b(1,1) = NaN; % from I
b = repmat(b, nRows*R, nCols*C);

rows = 1 : nRows; 
cols = 1 : nCols;

for ii = 0:nRows-1,
  for jj = 0:nCols-1,
    kk = jj + ii * nCols + 1;
    if kk <= F
      b((ii*R)+1:(ii+1)*R, (jj*C)+1:(jj+1)*C) = I(:,:,kk);
    else
      break;
    end
  end
end

X_hor = [64:64:size(I,2)*nCols-5;64:64:size(I,2)*nCols-5];
Y_hor = repmat([1; size(I,1)*nRows],1,size(X_hor,2));
Y_ver = [64:64:size(I,1)*nRows-5;64:64:size(I,1)*nRows-5];
X_ver = repmat([1; size(I,2)*nCols],1,size(Y_ver,2));

h = imagesc(b,lims); set(gca,'xticklabel',[],'xtick',[],'yticklabel',[],'ytick',[],'ydir','normal');
%xlabel('Gb'), ylabel('Gr');
line([X_hor X_ver],[Y_hor Y_ver],'color','y');
colorbar;

