function [I_error,loc] = pix_defect(I,k,FSD,theta)

% PIX_DEFECT     - Analyses image to find possible defective pixels
%                  (SMIA 1.0 characterization 2.2.3 and 2.2.4)
%
% Function call:    [I_error,loc] = pix_defect(I,k,FSD,theta);
%
% In:   I           3D-image (R,G1/Gr,B,G2/Gb) (if not given, uses uigetfile for file name)
%       k           Kernel size (+/-k pixels around analyzed pixel, default 1)
%       FSD         Full scale deflection for camera
%       theta       threshold for defectiveness as % of FSD (default 15)
%
% Out:  I_error     Error image
%       loc         Location and value of defective pixels in each color component
%                   plus percentage of defective pixels from total pixels
%                   for each component
%                   (struct)

% (c) Heli Hytti 14.9.2005
% HH 23.2.2006: arbitrary number of color channels

if nargin<4, theta = 15; end
if nargin<2, k = 1; end

theta = theta/100;

if (nargin<1 | isempty(I)), [f, p] = uigetfile('*.*','Select image file');
  ext = f(end-2:end);
  I = readraw([p f],'O');
end

I = double(I);
nc = size(I,3);

Kern = ones(2*k+1)/((2*k+1)^2-1);
I_error = zeros(size(I));
loc = struct('ch1',[]);

for ii=1:nc,
  a_bar = conv2(I(:,:,ii),Kern,'valid')-(I(k+1:end-k,k+1:end-k,ii)/((2*k+1)^2-1));
  I_error(k+1:end-k,k+1:end-k,ii) = I(k+1:end-k,k+1:end-k,ii)-a_bar;
  Ie = I_error(:,:,ii);
  Ic = I(:,:,ii);
  [R,C] = find(Ie>theta*FSD); V = Ic(Ie>theta*FSD); 
  rat = 100*length(V)/(size(I,1)*size(I,2));
  eval(['loc.ch' num2str(ii) ' = [R C V]; loc.def_ratio(ii) = rat;']);
end
