function plot_oecf(ext, val, mean_in)

% PLOT_OECF        - Plots opto-electronic conversion function (OECF)
%
% Function call:    plot_oecf(ext, val, mean_in);
%
% In:   ext         file name extension (e.g. 'x3f')
%       val         logarithmic exposure values
%       mean_in     cell array containing
%                   ch_mean1, ch_mean2 etc: Means of color components of average images

% (c) Heli Hytti 21.2.2005
% HH 22.2.2006: arbitrary number of color channels

nc = size(mean_in,2);
[sv,Iv] = sort(val);

if nc==1, lcolor = 'k'; lmarker = 'none';
elseif nc==3, lcolor = str2mat('r','g','b'); lmarker = str2mat('.','+','x');
elseif nc==4, lcolor = str2mat('r','g','b','g'); lmarker = str2mat('.','+','.','x');
end

figure;
for ii=1:nc, 
  vec = mean_in{ii};
  h = line(sv,log2(vec(Iv)),'linestyle','-','linewidth',2,'color',lcolor(ii,:),'marker',lmarker(ii,:)); 
end

xlabel('log_1_0 Input exposure'); ylabel('log_2 Digital output level'); title('Camera OECF');
