function plot_ptc(ext, S, std_S, std_FPN)

% PLOT_PTC       - Plots photon transfer curve (PTC)
%
% Function call:    plot_ptc(ext, S, std_S, std_FPN);
%
% In:   ext         file name extension (e.g. 'x3f')
%       S           Averages of mean red, green and blue digital values for each exposure level
%       std_S       Averages of STDs of differenced red, green and blue components
%       std_FPN     Fixed pattern noise STDs for color components

% (c) Heli Hytti 10.2.2005
% HH 7.9.2005: each color component plotted in separate window
% HH 21.2.2006: arbitrary number of color channels

nc = size(S,2);
if nc==1, cnames = 'Grayscale';
elseif nc==3, cnames = str2mat('Red','Green','Blue');
elseif nc==4, cnames = str2mat('Red','G-red','Blue','G-blue');
end

%warning('OFF','Log of zero.');

for ii=1:nc,
  figure; 
  h1 = line(log2(S(:,ii)),log2(std_S(:,ii)),'linestyle','-','linewidth',2,'color','r','marker','x');
  h2 = line(log2(S(:,ii)),log2(std_FPN(:,ii)),'linestyle','-','linewidth',2,'color','m','marker','x');
  h3 = line(log2(S(:,ii)),log2(sqrt(std_FPN(:,ii).^2+std_S(:,ii).^2)),'linestyle','-','linewidth',2,'color','c','marker','x');
  title(['Photon transfer curve, ' deblank(cnames(ii,:))]); xlabel('log_2 S(DN)'); ylabel('log_2 STD(DN)');
  axis('equal');
  legend([h1 h2 h3],str2mat('Temporal noise','FP noise','Total noise'),'location','best');
end
  
%warning('ON','Log of zero.');
