function I = readraw(fname, opt)
% readraw - reads image from raw file
%
% I = readraw(fname, opt);
%
%  in: fname   any 'raw' filename
%
% out: I       (uint16 or uint8) image
%      opt     read options character string (default none - uint8 true-color)
%               'L' - 16-bit linear true-color
%               'O' - raw binary, 'c' - color corrected raw binary
%               'rM' - include black margins into raw binary
%
% Note: Uses dcraw_any.exe (modified from Dave Coffins dcraw by HI) or
% imread.m

% (c) Heimo Ihalainen 27.11.2004
% Updated 26.7.2005 Riku Pelander
% Updated 28.2.2006 Heli Hytti; imread option added to reading files

ftype = fname(end-2:end);
[out,FMT] = isvalidext(ftype);
if out==1, I = imread(fname);
else
    op = ''; fty = 'p'; cmd = 'dcraw_any ';
    % Uncomment the following for unix use /RP
    %op = ''; fty = 'p'; cmd = './dcraw_any ';
    if nargin<2;
    elseif any(lower(opt)=='l'); op = '-4 ';
    else fty = 'b'; op = '-h -U ';
      if any(lower(opt)=='c'); op = [op '-P '];
      else op = [op '-O '] ;
      end
      if any(lower(opt)=='m'); op = [op '-M ']; end
    end

    switch fty
      case 'p'; [status, output] = dos([cmd op fname]);
        I = imread([fname(1:end-3) 'ppm']); delete([fname(1:end-3) 'ppm']);
      case 'b'; [status, output] = dos([cmd op fname]);
      % Uncomment the following for unix use /RP
      %  case 'b'; [status, output] = unix([cmd op fname]); 
        if all(lower(fname(end-2:end))=='x3f'); nc = 3; else nc = 4; end
        fid = fopen([fname(1:end-3) 'bin'], 'rb');
        nw = fread(fid, 1, 'uint32'); nh = fread(fid, 1, 'uint32');
        if nc==3; I = repmat(uint16(0), [nh nw nc]); J = uint16(fread(fid, [nc+1, nw * nh], 'int16=>int16') + 63);
        else I = repmat(uint16(0), [nh nw nc]); J = fread(fid, [nc, nw * nh], 'uint16=>uint16');
        end; ok = fclose(fid);
        K = reshape(J, [4 nw nh]); I(:) = permute(K(1:nc,:,:), [3 2 1]);
        delete([fname(1:end-3) 'bin']);
    end

    if opt=='O',
       if all(lower(fname(end-2:end))=='nef'); I = I(:,1:end-1,:);
       elseif all(lower(fname(end-2:end))=='x3f'); I = I(9:1520,19:2286,:);
       end
    end
end
