function [mb_a, vb_a, n] = regh(h, a, b);

% REGH   - Computes regression from 2D-histogram h.
%
% Function call:    [mb_a, vb_a] = regh(h, a, b);
%
% In:	h       2D-histogram counts h
%       a, b    variable axes a and b
%
% Out:	mb_a    conditional mean of b on a
%       vb_a    conditional variance of b on a
%       n       degrees of freedom

% (c) Heimo Ihalainen 6.10.2002

N = sum(sum(h)); pab = h/N;
pa = sum(pab); pb = sum(pab');
ia = find(pa>0);
mb_a = repmat(nan, size(pa,2), 1); vb_a = mb_a; n = zeros(size(pa,2), 1);
for ii=ia;
  n(ii) = N*pa(ii);
  mb_a(ii) = sum(pab(:,ii).*b)/pa(ii);
  if n(ii)>1; vb_a(ii) = (sum(pab(:,ii).*b.*b)/pa(ii) - mb_a(ii)*mb_a(ii))*n(ii)/(n(ii)-1); end
end
