function out = single_images(dname, ext, index, trm)

% SINGLE_IMAGES       - Displays individual images, both with and without trend
%
% Function call:    out = single_images(dname,ext,index,trm);
%
% In:   dname       Directory name for data files
%       ext         file name extension (e.g. 'x3f')
%       index       Index numbers for files to be shown
%                   (time order in directory dname) or file names in cell
%                   array
%       trm         trend removal yes = 1, no = 0 (default = 0)
%
% Out:  out         cell array containg:
%                   ch1, ch2 etc: 3D matrix of color components with trend
%                   Tch1, Tch2 etc: trendless averages for color
%                   components

% (c) Heli Hytti 3.2.2005
% HH 23.2.2006: arbitrary number of color channels

% Add backslash to the end of directory name if it's missing
if dname(end)~='\', dname = [dname '\']; end

if nargin<4, trm = 0; end

% Get file names
if nargin<3, F = files(dname,ext,'t'); Ns = size(F,2); index = 1:Ns; 
elseif iscell(index), F = index; index = 1:length(F);
else F = files(dname,ext,'t');
end

% Read first image
I = readraw([dname F{index(1)}],'O');
nw = size(I,2); nh = size(I,1); nc = size(I,3);

if nc==1, cnames = 'Grayscale';
elseif nc==3, cnames = str2mat('Red','Green','Blue');
elseif nc==4, cnames = str2mat('Red','G-red','Blue','G-blue');
end

% Initialize output matrices
for kk=1:nc, eval(['ch' num2str(kk) ' = zeros(nh,nw,length(index));']);
  if trm==1, eval(['Tch' num2str(kk) ' = zeros(nh,nw,length(index));']); end
end

if trm==1,
    % Trend removal filter
    [ba, aa] = besself(2, 0.01*2*pi); [b, a] = impinvar(ba, aa, 1);
    X = zeros(1001); X(501,501)=1; H = filtsk(X, b, a); sH = sum(H(:));
    H(:) = H/sH; b = b/sH;
end

% Divide first image into color components and put them into output
% matrices
for kk=1:nc, eval(['ch' num2str(kk) '(:,:,1) = double(I(:,:,kk));']);
  if trm==1, eval(['Tch' num2str(kk) '(:,:,1) = ch' num2str(kk) '(:,:,1)-filtsk(ch' num2str(kk) '(:,:,1),b,a);']); end
end

for ii=2:length(index),
    % Read images
    I(:) = readraw([dname F{index(ii)}],'O');
    for kk=1:nc, eval(['ch' num2str(kk) '(:,:,ii) = double(I(:,:,kk));']);
       if trm==1, eval(['Tch' num2str(kk) '(:,:,ii) = ch' num2str(kk) '(:,:,ii)-filtsk(ch' num2str(kk) '(:,:,ii),b,a);']); end
    end
end

for ii=1:length(index),
  for kk=1:nc,
    figure; eval(['imagesc(ch' num2str(kk) '(:,:,ii));']); title([deblank(cnames(kk,:)) ' ' num2str(index(ii))]); colormap gray; colorbar
    if trm==1,  
        figure; eval(['imagesc(Tch' num2str(kk) '(:,:,ii));']); title([deblank(cnames(kk,:)) ' (trendless) ' num2str(index(ii))]); colormap gray; colorbar
    end
  end
end    

if trm==0,
  out = cell(1,nc);
  for ii=1:nc, out(ii) = eval(['{ch' num2str(ii) '};']); end
else
  out = cell(1,2*nc);
  for ii=1:nc, out(ii) = eval(['{ch' num2str(ii) '};']); end
  for ii=nc+1:2*nc, out(ii) = eval(['{Tch' num2str(ii-nc) '};']); end
end
