function r = xcor(x, md)

%	r = xcor([x y], md)
%
%	xcor	computes the correlation function between signal couple.
%
%   in:	[x y]	two variate signal formed by signals to be correlated.
%		(If given univariate signal, autocorrelation is calculated.)
%	md	maximum delay calculated (default maximum possible)
%
%  out:	r	correlation function of delay values -md...md

% (c) Heimo Ihalainen 30.5.1989 (26.1.91 HI)

[N,p] = size(x);
if p>N; error('Wrong form of vector(s) - should be column!'); end
if nargin<2; md = N-1; end; md = min(abs(md),N-1);

if N<200;					% direct calculation
  r1 = filter(x(N:-1:1,p),1,[x(:,1);zeros(N-1,1)]); r = r1(N-md:N+md)/N;
else;						% use FFT
  if md>0.4*N; Nf = 2^ceil(log(N)/log(2)-10*eps);% straight method
    x(Nf+Nf,1) = 0;
    if p==1; r1 = conj(fft(abs(fft(x(:,1))).^2));
    else r1 = conj(fft(conj((fft(x(:,1)).*conj(fft(x(:,p)))))));
    end; r = [r1(Nf+Nf-md+1:Nf+Nf);r1(1:md+1)]/N/(Nf+Nf);
  else; Nf = 2^ceil(log(md)/log(2)+1-10*eps);	% overlap-add
    N2 = Nf/2; inx = 1:N2; iny = 1:Nf; zer = zeros(N2,1);
    x(N+Nf,1) = 0; S1 = zeros(Nf,1); S2 = zeros(Nf,1);
    for i=1:ceil(N/N2)
      S1(:) = S1 + fft([x(inx,1);zer]).*conj(fft(x(iny,p)));
      if p>1; S2(:) = S2 + fft([x(inx,p);zer]).*conj(fft(x(iny,1))); end
      iny = iny+N2; inx = inx+N2;
    end
    r1 = conj(fft(conj(S1)));
    if p>1; r2 = conj(fft(conj(S2)));
      r = [r1(Nf-md+1:Nf);r2(1);r2(Nf:-1:Nf-md+1)]/N/Nf;
    else r = [r1(Nf-md+1:Nf);r1(1);r1(Nf:-1:Nf-md+1)]/N/Nf;
    end
  end
  if ~any(imag(x)); r(:) = real(r); end
end
