%Obtain polynomial transformations between two colour spaces RGB and QFA


function [Mat, SEE] = PolynomialCoefficients(RGBs, QFAs, plotit, M3)
%
%QFA is the ground truth
%RGBs is the space I want to map
%plotit tells the program if you want a plot of the fits
%M3 (when M3==1) tells the program that we just want a 3x3 matrix intead of the poly.
if (nargin < 4) || isempty(M3)
    M3 = 0;
end
if (nargin < 3) || isempty(plotit)
    plotit = 0;
end

l1= 0.75;

if M3 % the transfromation is done by a 3x3 matrix
    RGB=RGBs;
else
    RGB=[RGBs RGBs(:,1).*RGBs(:,2) RGBs(:,2).*RGBs(:,3) RGBs(:,1).*RGBs(:,3)];
end

Mat=(RGB\QFAs)';
SEE = sum((RGB*Mat'-QFAs).^2 ,1); %sum of squared residuals


if plotit
    RGB1=RGB*Mat';
    p = polyfit(RGB1(:,1), QFAs(:,1),1); maxx= max(RGB1(:,1)); maxy=max(QFAs(:,1)); 
    figure; plot(RGB1(:,1), QFAs(:,1), '.','color','r'); text(maxx./4,maxy.*l1,'Channel 1'); 
    text(maxx./4,maxy.*(l1-0.05),strcat('slope= ',num2str(p(1)))); hold on;
    text(maxx./4,maxy.*(l1-0.1),strcat('SEE= ',num2str(SEE(1),'%10.2e\n'))); hold on;
    line([0;maxx],[p(2);p(1).*maxx],'color',[0 0 0]); 
    axis([0 maxx 0 max(QFAs(:,1))]);
    
    p = polyfit(RGB1(:,2), QFAs(:,2),1); maxx= max(RGB1(:,2)); maxy=max(QFAs(:,2));    
    figure; plot(RGB1(:,2), QFAs(:,2), '.','color','g'); text(maxx./4,maxy.*l1,'Channel 2'); 
    text(maxx./4,maxy.*(l1-0.05),strcat('slope= ',num2str(p(1)))); hold on;
    text(maxx./4,maxy.*(l1-0.1),strcat('SEE= ',num2str(SEE(2),'%10.2e\n'))); hold on;    
    line([0;maxx],[p(2);p(1).*maxx],'color',[0 0 0]);
    axis([0 maxx 0 max(QFAs(:,2))]);
    
    p = polyfit(RGB1(:,3), QFAs(:,3),1); maxx= max(RGB1(:,3)); maxy=max(QFAs(:,3));    
    figure; plot(RGB1(:,3), QFAs(:,3), '.','color','b'); text(maxx./4,maxy.*l1,'Channel 3');
    text(maxx./4,maxy.*(l1-0.05),strcat('slope= ',num2str(p(1)))); hold on;
    text(maxx./4,maxy.*(l1-0.1),strcat('SEE= ',num2str(SEE(3),'%10.2e\n'))); hold on;    
    line([0;maxx],[p(2);p(1).*maxx],'color',[0 0 0]);
     axis([0 maxx 0 max(QFAs(:,3))]);
     hold off;
end
    
        
