function Q = fovRGB2OtherFormat(foveon_pic, M, f_number, integrationtime, linearizefoveon)
%Converts the Sigma Foveon picture into LMS or XYZ or whatever according to
%the values of Matix M passed. If a string containing the filename of the
%picture considered is passed, it will read the picture header and do the
%calculations.

if nargin < 5 || isempty(linearizefoveon)
    linearizefoveon = 1;
end

if ischar(foveon_pic)   
    [pathstr, name, ext, versn] = fileparts(foveon_pic);
    if ~strcmpi(ext,'X3F')
        error('wrong file extension');
    end
    h = read_x3f_header(foveon_pic);
    f_number = str2double(h.APERTURE);
    integrationtime = str2double(h.SHUTTER);
else
    if (nargin < 4) || isempty(integrationtime)
            integrationtime = 1/250; % estimated from a typica sunny image of Barcelona
    end
    if (nargin < 3) || isempty(f_number)
            f_number = 7.1; % estimated from a typica sunny image of Barcelona
    end
end

if (nargin < 2) || isempty(M)
        load ('sigma_foveon.mat'); %sensors
        temp = 6500;    %D65 = default illuminant
        interval = [400 700];
        load('BW_IR486.mat'); %IRblocking
        k = 1;
        disp('Default: CIE1931 XYZ (normalised to max=1) and Munsell chips');
        load('munsell1269.mat');    %reflec
        load('colour_matching_functions.mat'); %XYZCIE1931_1nm
        RGBmunsell = sensors_capture(sensors_normalised, reflec, temp, interval, IRblocking);
        XYZmunsell = sensors_capture(XYZCIE1931_1nm, reflec, temp, interval, 0, k);
        [M SumSQResid] = PolynomialCoefficients(RGBmunsell,XYZmunsell,1);    
end

if linearizefoveon
    P = linearise_foveon_pic(foveon_pic);
else 
    P = foveon_pic;
end
[lin col pla] = size(P);
f_number = repmat(f_number,lin*col,1);
integrationtime = repmat(integrationtime,lin*col,1);
Konst1= 690; %to square physical units
Konst0 = 4 .* (f_number).^2 ./ pi() ./ integrationtime ;
Konst = repmat(Konst0,1,3);
P = Konst .* reshape(P,lin*col,pla);

Q = Konst1 .* (P * M(:,1:3)' + P(:,1) .* P(:,2) * M(:,4)' + P(:,2) .* P(:,3) * M(:,5)' + P(:,1) .* P(:,3) * M(:,6)');

Q = Q.*(Q >= 0); %truncates anything below 0;

Q = reshape(Q, lin, col, pla);







