% This is an improved version of the old get_me_the_sky
%It basically accepts any wavelenght interval from 300 to 830 nm
% with any interval step. The defaults are the obvious ones [400nm 700nm]
% in 10 nm steps.
%It uses matlab's spline to interpolate data.


%This glorious function will produce spectral illuminant data from any colour temperature 
%Examples:
%   Noon= 25000K
%   Evening= 4300K
%   D65 = 6500K

%Temperature Typical Sources 
%1000K Candles; oil lamps 
%2000K Very early sunrise; low effect tungsten lamps 
%2500K Household light bulbs 
%3000K Studio lights, photo floods 
%4000K Clear flashbulbs 
%5000K Typical daylight; electronic flash 
%5500K The sun at noon near Kodak's offices :-) 
%6000K Bright sunshine with clear sky 
%7000K Slightly overcast sky 
%8000K Hazy sky 
%9000K Open shade on clear day 
%10,000K Heavily overcast sky 
%11,000K Sunless blue skies 
%20,000+K Open shade in mountains on a really clear day 

%Actual nerdy calculations:
%===========================================================================================
%Temp 4000K to 7000K		xD = -4.6070*10^9/Tc^3+2.9678*10^6/Tc^2+0.09911*10^3/Tc+0.244063					
%Temp 7000K to 25,000	    xD = -2.0064*10^9/Tc^3+1.9018*10^6/Tc^2+0.24748*10^3/Tc+0.23704					
%		yD = -3.000*xD^2 + 2.870*xD - 0.275					
%		M1 = (-1.3515 - 1.7703*xD + 5.9114*yD)/(0.0241 + 0.2562*xD  - .7341*yD)					
%		M2 = (0.0300 - 31.4424*xD + 30.0717*yD)/(0.0241 + 0.2562*xD  - .7341*yD)					
%		SD(lamda) = S0(lamda) + M1*S1(lamda) + M2*S2(lamda)	
%===========================================================================================


% Power indicates the output value for lambda= 560 nm  

function light= get_me_the_sky(Tc,limits, step, power)

if nargin<4
    power = 100;
end
if nargin<3
    step = 10;
end
if nargin<2
    limits = [400 700];
end

    %Color Science: Concepts and Methods, Quantitative Data and Formulae			
    %Wyszecki and Stiles			
    %Table V(3.3.4) 			
    %Mean Relative Spectral Radiant Power Distribution S0(lamda) and First Two			
    %Eigenvectors S1(lamda) and S2(lamda) Used in CIE Method of Calculating Daylight			
    %Illuminants			
    %nm S0(lamda)	S1(lamda)	S2(lamda)
Illum_all =[300     0.04    0.02    0.0;
            310     6.0     4.5     2.0;
            320     29.6    22.4    4.0;
            330     55.3    42.0    8.5;
            340     57.3    40.6    7.8;
            350     61.8    41.6    6.7;
            360     61.5    38.0    5.3;
            370     68.8    42.4    6.1;
            380     63.4    38.5    3.0;
            390     65.8    35.0    1.2;
            400     94.8	43.4	-1.1;
            410     104.8	46.3	-0.5;
            420     105.9	43.9	-0.7;
            430     96.8	37.1	-1.2;
            440     113.9	36.7	-2.6;
            450     125.6	35.9	-2.9;
            460     125.5	32.6	-2.8;
            470     121.3	27.9	-2.6;
            480     121.3	24.3	-2.6;
            490     113.5	20.1	-1.8;
            500     113.1	16.2	-1.5;
            510     110.8	13.2	-1.3;
            520     106.5	8.6	    -1.2;
            530     108.8	6.1	    -1;
            540     105.3	4.2	    -0.5;
            550     104.4	1.9	    -0.3;
            560     100	    0	    0;
            570     96	    -1.6	0.2;
            580     95.1	-3.5	0.5;
            590     89.1	-3.5	2.1;
            600     90.5	-5.8	3.2;
            610     90.3	-7.2	4.1;
            620     88.4	-8.6	4.7;
            630     84	    -9.5	5.1;
            640     85.1	-10.9	6.7;
            650     81.9	-10.7	7.3;
            660     82.6	-12	    8.6;
            670     84.9	-14	    9.8;
            680     81.3	-13.6	10.2;
            690     71.9	-12	    8.3;
            700     74.3	-13.3	9.6;
            710     76.4    -12.9   8.5;
            720     63.3    -10.6   7.0;
            730     71.7    -11.6   7.6;
            740     77.0    -12.2   8.0;
            750     65.2    -10.2   6.7;
            760     47.7    -7.8    5.2;
            770     68.6    -11.2   7.4;
            780     65.0    -10.4   6.8;
            790     66.0    -10.6   7.0;
            800     61.0    -9.7    6.4;
            810     53.3    -8.3    5.5;
            820     58.9    -9.3    6.1;
            830     61.9    -9.8    6.5];

searchrange = 300:step:830;
minim = find(searchrange==limits(1));
maxim = find(searchrange==limits(2));
if or(isempty(minim), isempty(maxim))
    error('Limits must be between 300-830 nm');
end

if (step == 10) &&  (mod(limits(1),10)==0)
    Illum = Illum_all(minim:maxim,2:4);
else % use SPLINE to interpolate
    x = Illum_all(:,1)';
    xx = searchrange(minim:maxim);
    cs = spline(x,Illum_all(:,2)');
    S0 = ppval(cs,xx);
    cs = spline(x,Illum_all(:,3)');
    S1 = ppval(cs,xx);
    cs = spline(x,Illum_all(:,4)');
    S2 = ppval(cs,xx);   
    Illum = [S0' S1' S2'];
end

%---------------
if (Tc>=4000 && Tc<7000)    
    xD = -4.607*10^9/Tc^3+2.9678*10^6/Tc^2+0.09911*10^3/Tc+0.244063;
elseif (Tc>=7000 && Tc<=25000)
    xD = -2.0064*10^9/Tc^3+1.9018*10^6/Tc^2+0.24748*10^3/Tc+0.23704;
    
else disp('ERROR: Colout Temperature must be between 4000 and 25000');
end
  

yD=-3*xD^2 + 2.87*xD - 0.275;

M_1=(-1.3515 - 1.7703*xD + 5.9114*yD)/(0.0241 + 0.2562*xD  - 0.7341*yD);
M_2=(0.03 - 31.4424*xD + 30.0717*yD)/(0.0241 + 0.2562*xD  - 0.7341*yD);
light = Illum(:,1)+M_1*Illum(:,2)+M_2*Illum(:,3);

light = light./100.*power;
