function capture = sensors_capture(sensors, reflec, temp, interval, IRblocking, k)

%Obtains the energy capture of a number of sensors when acting over a
%surface of spectral reflectance (reflec), illuminated by a plankian light
%source of temperature K, though a filter (IRblocking).
%variables:
%1)sensors: the sensors' sensitivities functions n x 4 varaible.
%2)reflect: the spectral reflectances n x m where n are the wavelenghts and m
%  is the total number of surfaces (reflectance functions) involved.
%3)temp: the temperature of the plankian illuminant (in Kelvin degrees)
%4)interval: the wavelength interval to be considered. All functions will
%  be interpolated to 1nm step if needed. the default interval is the visible
%  [400 700] nm.
%5)IRblocking: in case ther is an extra filter here is the place to add it.
%  We have used an IR-blocking filter which is our default.
%6)k: a multiplicative constant that might be useful some times to scale
%  results.


if (nargin < 6) || isempty(k);
    k= 1; % multiplicative constant
end
if nargin < 5 || isempty(IRblocking)
    load('BW_IR486.mat'); %IRblocking
end
if nargin < 4 || isempty(interval)
    interval = [400 700];
end
if nargin < 3 || isempty(temp)
    temp = 6500;    %D65 = default illuminant   
end
if nargin < 2 || isempty(reflec)
    load('munsell1269.mat'); %reflec
end
if nargin < 1 || isempty(sensors)
    load ('sigma_foveon.mat'); %sensors
end

if IRblocking == 0
    IRblocking = [(interval(1):1:interval(2))', ones(interval(2)-interval(1)+1,1)];
end  
if temp==0
    illum = ones(interval(2)-interval(1)+1,1);
elseif size(temp,2)>1
    illum = ones(interval(2)-interval(1)+1,size(temp,2));
    for ii=1:size(temp,2)
        illum(:,ii) = get_me_the_sky(temp(ii),interval, 1, 1);
    end
else
    illum = get_me_the_sky(temp,interval, 1, 1);
end

if ~all(ismember(400:700,reflec(:,1)))
    reflec=interp1(reflec(:,1),reflec(:,2:end),400:700);
else
    reflec=reflec(ismember(reflec(:,1),400:700),2:end);
end
reflin= size(reflec,2);

if ~all(ismember(400:700,sensors(:,1)))
    sensors=interp1(sensors(:,1),sensors(:,2:end),400:700);
else
	sensors = sensors(ismember(sensors(:,1),400:700),2:end);        
end
if ~all(ismember(400:700,IRblocking(:,1)))
    IRblocking=interp1(IRblocking(:,1),IRblocking(:,2:end),400:700);
else
	IRblocking = IRblocking(ismember(IRblocking(:,1),400:700),2:end);        
end

if k~=1
    konst = repmat(k,reflin .* size(temp,2),3);
    sensors = sensors.* konst;
end
capture = zeros(reflin.* size(illum,2),3);   

%This is faster but does not work for bi arrays
%capture = (repmat(reflec,1,size(illum,2)) .*(repmat(illum,1,reflin)))' * (sensors .* repmat(IRblocking,1,size(sensors,2)));

sens = sensors .* repmat(IRblocking,1,size(sensors,2));

kk=1;
for ii=1:size(illum,2)
    for jj=1:reflin
    
    capture(kk,:)= (reflec(:,jj) .* illum(:,ii))' * sens;
    kk= kk+1;
        
    end
end



% sensors = sensors(find(sensors(:,1)>=interval(1) & sensors(:,1)<= interval(2)),2:4);
% reflec  = reflec(find(reflec(:,1)>=interval(1) & reflec(:,1)<= interval(2)),2:refcol);



